
class _WotAuthApi {
    constructor() {
        this.root = 'https://auth.api.mywot.com';
    }
    post(url, data) {
        let callback = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : () => {};

        let xhr = new XMLHttpRequest(),
            start = +new Date();
        xhr.open("POST", url);
        xhr.setRequestHeader("Content-Type", "application/json");
        xhr.onload = () => {
            xhr.time = +new Date() - start;
            return callback.call(null, xhr);
        };
        xhr.send(JSON.stringify(data));
    }
    get(url, data, headers) {
        let callback = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : () => {};

        if (typeof headers === 'function') {
            callback = headers;
            headers = {};
        }
        let xhr = new XMLHttpRequest(),
            start = +new Date();
        xhr.open("get", url + (url.indexOf('?') !== -1 ? '' : '?') + Object.keys(data).map(key => {
            return key + '=' + encodeURIComponent(data[key]);
        }).join('&'));
        for (let header in headers) {
            xhr.setRequestHeader(header, headers[header]);
        }
        xhr.onload = () => {
            xhr.time = +new Date() - start;
            return callback.call(null, xhr);
        };
        xhr.send();
    }
    getUser(token) {
        let params = '';
        let url = this.root + '/me';
        return new Promise((resolve, reject) => {
            this.get(url, params, { "Authorization": "Bearer " + token, "Content-Type": "text/plain" }, xhr => {
                let parsedResponse = undefined;
                try {
                    parsedResponse = JSON.parse(xhr.responseText);
                } catch (e) {
                    parsedResponse = { code: 4006, message: "You've been logged out. Please login again" };
                }
                let status = parsedResponse.score && parseStatus(parsedResponse.score);
                !parsedResponse.roles[6] && status && (parsedResponse.roles[6] = status);
                if (parsedResponse.roles[7]) {
                    parsedResponse.roles[6] = parsedResponse.roles[7];
                } else if (parsedResponse.roles[8]) {
                    parsedResponse.roles[6] = parsedResponse.roles[8];
                } else if (parsedResponse.roles[9]) {
                    parsedResponse.roles[6] = parsedResponse.roles[9];
                } else if (parsedResponse.roles[10]) {
                    parsedResponse.roles[6] = parsedResponse.roles[10];
                }
                if (xhr.status === 200) {
                    resolve(parsedResponse);
                } else {
                    ;
                    //
                    reject({ code: parsedResponse.code, message: parsedResponse.message });
                }
            });
        });
    }
    login(username, password) {
        let params = typeof username === "object" ? username : { username: username, password: password };
        let url = this.root + '/token?';
        return new Promise((resolve, reject) => {
            this.post(url, params, xhr => {
                let parsedResponse = JSON.parse(xhr.responseText);
                if (xhr.status === 200) {
                    let token = parsedResponse.token;
                    resolve(token);
                } else {
                    ;
                    //
                    reject({ code: parsedResponse.code, message: parsedResponse.message });
                }
            });
        });
    }
    logout() {
        let url = this.root + '/logout';
        return new Promise((resolve, reject) => {
            this.post(url, {}, xhr => {
                if (xhr.status === 200) {
                    resolve(token);
                } else {
                    reject(xhr.status);
                }
            });
        });
    }
    register(name, mail, pass, Pass2) {
        let params = typeof name === "object" ? name : { name: name, mail: mail, pass: pass, Pass2: Pass2 };
        let url = this.root + '/signup?';
        return new Promise((resolve, reject) => {
            this.post(url, _.merge({}, params, { Pass2: params.Pass2 || params.pass }), xhr => {
                let parsedResponse = JSON.parse(xhr.responseText);
                if (xhr.status === 200) {
                    if (parsedResponse.status === 400) {
                        ;
                        reject({ code: parsedResponse.code, message: parsedResponse.message });
                    }
                    let token = parsedResponse.token;
                    resolve(token);
                } else {
                    ;
                    //
                    reject({ code: parsedResponse.code, message: parsedResponse.message });
                }
            });
        });
    }
    forgot(username) {
        let params = typeof username === "object" ? username : { username: username };
        let url = this.root + '/forgot-pass?';
        return new Promise((resolve, reject) => {
            this.post(url, _.merge({}, params), xhr => {
                let parsedResponse = JSON.parse(xhr.responseText);
                if (xhr.status === 200) {
                    resolve(parsedResponse);
                } else {
                    ;
                    //
                    reject({ code: parsedResponse.code, message: parsedResponse.message });
                }
            });
        });
    }
    socialLoginUrl(network) {
        return this.root + "/" + network + '?source=extension';
    }
}
let WotAuthApi = new _WotAuthApi();